@@ -6,12 +6,7 @@ from django.contrib.sites.models import Site
 
 SiteData = namedtuple('SiteData', 'name domain logo team')
 
-from lime.conf import get_setting
-
-SITE_NAME = get_setting('SITE_NAME')
-SITE_DOMAIN = get_setting('SITE_DOMAIN')
-SITE_LOGO = get_setting('SITE_LOGO')
-SITE_TEAM = get_setting('SITE_TEAM')
+from lime.settings import SITE_NAME, SITE_DOMAIN, SITE_LOGO, SITE_TEAM
 
 site = None
 
